@@ -2,10 +2,10 @@
 import sys
 
 # Local
-import utilities.chatgpt as gpt
-import utilities.parsers as parsers
-import utilities.printers as printers
-import utilities.code_execution as code_exec
+import stackexplain.utilities.chatgpt as gpt
+import stackexplain.utilities.parsers as parsers
+import stackexplain.utilities.printers as printers
+import stackexplain.utilities.code_execution as code_exec
 
 
 ######
